
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.15.3.post1',
    'branch_nick': '(detached',
    'revision_id': 'ebae01ca3f42eba4d8960571c52a04f07488f775',
    'revno': 6364
}
